/*
 *      This program is free software; you can redistribute it and/or modify
 *      it under the terms of the GNU General Public License as published by
 *      the Free Software Foundation; either version 2 of the License, or
 *      (at your option) any later version.
 *      
 *      This program is distributed in the hope that it will be useful,
 *      but WITHOUT ANY WARRANTY; without even the implied warranty of
 *      MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *      GNU General Public License for more details.
 *      
 *      Last Modified : 2 Dec. 2014
 *      Written by Gyeongyong Heo
 *      Contact Info. hgycap@deu.ac.kr
 */
 
byte pattern_previous, pattern_current;
int rules[] = {0, 1, 1, 1, 1, 0, 0, 0};	// 세포의 생성 소멸 규칙

int dataPin = 11;
int latchPin = 12;
int clockPin = 13;

void setup(){
	pinMode(dataPin, OUTPUT);
	pinMode(clockPin, OUTPUT);
	pinMode(latchPin, OUTPUT);

	pattern_previous = 0b00010000;		// 세포 자동자 초기 상태
	randomSeed(analogRead(A5));		// 랜덤 함수 초기화
}

void loop(){
	// 현재 상태 계산
	pattern_current = 0;
	for(int i = 0; i < 8; i++){
		int left = i + 1;			// 왼쪽 세포 인덱스
		int right = i - 1;			// 오른쪽 세포 인덱스

		int value_left, value_right;		// 이웃 세포의 상태
		if(left >= 8){				// 왼쪽 이웃 세포가 없는 경우
			value_left = random(0, 2);		// 0 또는 1로 임의로 결정
		}
		else{						// 왼쪽 이웃 세포의 상태 알아내기
			value_left = bitRead(pattern_previous, left);
		}

		if(right < 0){				// 오른쪽 이웃 세포가 없는 경우
			value_right = random(0, 2);		// 0 또는 1로 임의로 결정
		}
		else{						// 오른쪽 이웃 세포의 상태 알아내기
			value_right = bitRead(pattern_previous, right);
		}

		// 자신의 상태
		int value_center = bitRead(pattern_previous, i);

		// 자신과 이웃 세포들의 상태로 생성 규칙 번호 결정
		int index = value_left * 4 + value_center * 2 + value_right;
		// 현재 상태 기록
		bitWrite(pattern_current, i, rules[index]);
	}
	
	pattern_previous = pattern_current;
	
	digitalWrite(latchPin, LOW);				// 래치 출력 금지
	shiftOut(dataPin, clockPin, MSBFIRST, pattern_current);	// 데이터 출력
	digitalWrite(latchPin, HIGH);				// 래치 출력 허용

	delay(500);
}
