/*
 *      This program is free software; you can redistribute it and/or modify
 *      it under the terms of the GNU General Public License as published by
 *      the Free Software Foundation; either version 2 of the License, or
 *      (at your option) any later version.
 *      
 *      This program is distributed in the hope that it will be useful,
 *      but WITHOUT ANY WARRANTY; without even the implied warranty of
 *      MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *      GNU General Public License for more details.
 *      
 *      Last Modified : 2 Dec. 2014
 *      Written by Gyeongyong Heo
 *      Contact Info. hgycap@deu.ac.kr
 */
 
#include <Wire.h>
#include <Adafruit_MCP23017.h>

// 0에서 9까지 숫자 표현을 위한
// 세그먼트 a, b, c, d, e, f, g, dp의 패턴
byte patterns[] = {
	0xFC, 0x60, 0xDA, 0xF2, 0x66, 0xB6, 0xBE, 0xE4, 0xFE, 0xE6
};

Adafruit_MCP23017 mcp;		// MCP23017 칩 객체

int SEGMENT_DELAY = 5;		// 숫자 표시 사이의 시간 간격
int minutes = 12;			// 분 초기화
int seconds = 34;			// 초 초기화

int time_previous, time_current;

void setup() {  
	mcp.begin();				// 기본 0x20 주소 사용

	for(int i = 0; i < 16; i++){
		mcp.pinMode(i, OUTPUT);		// 버튼이 연결된 핀을 입력으로 설정
	}
	time_previous = millis();
}

// 해당 자리에 숫자 하나를 표시하는 함수
void show_digit(int pos, int number){	// (위치, 출력할 숫자)
	// 상위 4비트는 사용되지 않는다.
	int position_data = 0b00001111;
	// 해당 자리의 제어 선에만 LOW 값을 가하므로 해당 비트를 0으로 만든다.
	bitClear(position_data, (pos - 1));

	// 숫자 데이터. 세그먼트 a부터 세그먼트 dp 순서
	int number_data = patterns[number];

	// 자릿수 데이터와 숫자 데이터로 16비트 데이터 조합
	int output_data = (position_data << 8) | number_data; 

	// MCP23017로 출력
	mcp.writeGPIOAB(output_data);
}

void loop() {
	time_current = millis();

	if(time_current - time_previous >= 1000){
		time_previous = time_current;

		seconds++;			// 초 증가
		if(seconds == 60){		// 60초가 되면 분 증가
			seconds = 0;
			minutes++;			// 분 증가
			if(minutes == 60){		// 60분이 되면 0으로
				minutes = 0;
			}
		}
	}

	show_digit(1, seconds % 10);
	delay(SEGMENT_DELAY);
	show_digit(2, seconds / 10);
	delay(SEGMENT_DELAY);
	show_digit(3, minutes % 10);
	delay(SEGMENT_DELAY);
	show_digit(4, minutes / 10);
	delay(SEGMENT_DELAY);
}
