/*
 *      This program is free software; you can redistribute it and/or modify
 *      it under the terms of the GNU General Public License as published by
 *      the Free Software Foundation; either version 2 of the License, or
 *      (at your option) any later version.
 *      
 *      This program is distributed in the hope that it will be useful,
 *      but WITHOUT ANY WARRANTY; without even the implied warranty of
 *      MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *      GNU General Public License for more details.
 *      
 *      Last Modified : 2 Dec. 2014
 *      Written by Gyeongyong Heo
 *      Contact Info. hgycap@deu.ac.kr
 */
 
#include <LiquidCrystal.h>

// 핀 번호 (RS, E, DB4, DB5, DB6, DB7)
LiquidCrystal lcd(2, 3, 5, 6, 7, 8);		// LCD 연결

char state_table[3][3] = {			// 상태 테이블
	{-1, 0, -1},
	{0, 1, -1},
	{0, 1, -1}};

// 사용자 정의 문자 데이터
byte condition_good[8] = {
	B00000, B10001, B00000, B00000, B10001, B01110, B00000, B00000
};
byte condition_normal[8] = {
	B00000, B10001, B00000, B00000, B00000, B11111, B00000, B00000
};
byte condition_bad[8] = {
	B00000, B10001, B00000, B00000, B01110, B10001, B00000, B00000
};

void setup() {
	lcd.createChar(0, condition_good);	// 사용자 정의 문자 1 생성
	lcd.createChar(1, condition_normal);	// 사용자 정의 문자 2 생성
	lcd.createChar(2, condition_bad);	// 사용자 정의 문자 3 생성

	lcd.begin(16, 2);  		// LCD 크기 설정
	lcd.clear();				// LCD 화면 지우기
}

void loop() {
	int light = analogRead(A2);			// 광센서
	delay(10);
	light = analogRead(A2);
	delay(10);

	int val = analogRead(A1);			// 온도 센서
	delay(10);
	val = analogRead(A1);
	delay(10);

	float temperature = 500.0 * val / 1023.0;

	int row, col;
	if(light <= 500) row = 0;			// 조도 구간 나눔
	else if(light <= 900) row = 1;
	else row = 2;

	if(temperature <= 27) col = 0;			// 온도 구간 나눔
	else if(temperature <= 29) col = 1;
	else col = 2;

	int state = state_table[row][col];			// 현재 상태 결정

	lcd.home();
	lcd.print("Temp.:");
	lcd.print(temperature);			// 첫째 줄에 온도 출력
	lcd.setCursor(0, 1);
	lcd.print("Light:");
	lcd.print(light);				// 둘째 줄에 조도 출력

	lcd.setCursor(15, 0);
	switch(state){				// 사용자 정의 문자 출력
	case 1:
		lcd.write(byte(0)); break;
	case 0:
		lcd.write(byte(1)); break;
	case -1:
		lcd.write(byte(2)); break;
	}

	delay(500);
}
