/*
 *      This program is free software; you can redistribute it and/or modify
 *      it under the terms of the GNU General Public License as published by
 *      the Free Software Foundation; either version 2 of the License, or
 *      (at your option) any later version.
 *      
 *      This program is distributed in the hope that it will be useful,
 *      but WITHOUT ANY WARRANTY; without even the implied warranty of
 *      MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *      GNU General Public License for more details.
 *      
 *      Last Modified : 2 Dec. 2014
 *      Written by Gyeongyong Heo
 *      Contact Info. hgycap@deu.ac.kr
 */
 
#include <LiquidCrystal.h>

// 핀 번호 (RS, E, DB4, DB5, DB6, DB7)
LiquidCrystal lcd(2, 3, 5, 6, 7, 8);		// LCD 연결

char state_table[3][3] = {			// 상태 테이블
	{-1, 0, -1},
	{0, 1, -1},
	{0, 1, -1}};

// 사용자 정의 문자 데이터. 2차원 배열로 구성
byte conditions[3][8] = {
	{ B00000, B10001, B00000, B00000, B10001, B01110, B00000, B00000 },
	{ B00000, B10001, B00000, B00000, B00000, B11111, B00000, B00000 },
	{ B00000, B10001, B00000, B00000, B01110, B10001, B00000, B00000 }};

boolean toggle = true;			// 상태 아이콘 점멸
unsigned long time_current, time_previous;

void setup() {
	for(int i = 0; i < 3; i++)
		lcd.createChar(i, conditions[i]);	// 사용자 정의 문자 생성

	lcd.begin(16, 2);  			// LCD 크기 설정
	lcd.clear();					// LCD 화면 지우기

	time_previous = millis();
}

void loop() {
	time_current = millis();
	// 0.5초 간격으로 온도와 조도를 측정하여 출력
	if(time_current - time_previous >= 500){
		time_previous = time_current;
		toggle = !toggle;

		int light = analogRead(A2);		// 광센서
		delay(10);
		light = analogRead(A2);
		delay(10);

		int val = analogRead(A1);		// 온도 센서
		delay(10);
		val = analogRead(A1);
		delay(10);

		float temperature = 500.0 * val / 1023.0;

		int row, col;
		if(light <= 500) row = 0;		// 조도 구간 나눔
		else if(light <= 900) row = 1;
		else row = 2;

		if(temperature <= 27) col = 0;	// 온도 구간 나눔
		else if(temperature <= 29) col = 1;
		else col = 2;

		int state = state_table[row][col];	// 현재 상태 결정

		lcd.home();
		lcd.print("Temp.:");
		lcd.print(temperature);		// 첫째 줄에 온도 출력
		lcd.setCursor(0, 1);
		lcd.print("Light:");
		lcd.print(light);			// 둘째 줄에 조도 출력

		lcd.setCursor(15, 0);
		if(toggle){
			switch(state){			// 사용자 정의 문자 출력
			case 1:
				lcd.write(byte(0)); break;
			case 0:
				lcd.write(byte(1)); break;
			case -1:
				lcd.write(byte(2)); break;
			}
		}
		else							// 공백 출력
			lcd.write(' ');
	}
}
