/*
 *      This program is free software; you can redistribute it and/or modify
 *      it under the terms of the GNU General Public License as published by
 *      the Free Software Foundation; either version 2 of the License, or
 *      (at your option) any later version.
 *      
 *      This program is distributed in the hope that it will be useful,
 *      but WITHOUT ANY WARRANTY; without even the implied warranty of
 *      MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *      GNU General Public License for more details.
 *      
 *      Last Modified : 2 Dec. 2014
 *      Written by Gyeongyong Heo
 *      Contact Info. hgycap@deu.ac.kr
 */
 
#include <SoftwareSerial.h>
#include <DMUStyleMotor.h>

// SoftwareSerial(RX, TX) 형식으로 블루투스 모듈과 교차하여 연결된다.
// 2 -> TX of Bluetooth Module
// 3 -> RX of Bluetooth Module
SoftwareSerial BTSerial(2, 3);

void setup(){
	BTSerial.begin(9600);			// 블루투스 연결 초기화
	Serial.begin(9600);			// 시리얼 포트 초기화

	DMUStyleMotor.Enable(MOTOR1);	// 모터를 활성화 상태로 지정
	DMUStyleMotor.Enable(MOTOR2);
}

void loop(){
	if(BTSerial.available()){			// 블루투스로 명령어가 수신된 경우
		char command = BTSerial.read();	// 명령어 읽기
		Serial.println(String("Command \'") + command + "\' received.");

		switch(command){
		case 'R':
		case 'r':					// 모터 1 회전
			Serial.println("Motor 1 Start...");
			DMUStyleMotor.Rotate(MOTOR1, DIRECTION1, 127);
			break;
		case 'L':
		case 'l':					// 모터 2 회전
			Serial.println("Motor 2 Start...");
			DMUStyleMotor.Rotate(MOTOR2, DIRECTION1, 127);
			break;
		case 'S':
		case 's':					// 모터 정지
			Serial.println("Motor STOP !!");
			DMUStyleMotor.Stop(MOTOR1);
			DMUStyleMotor.Stop(MOTOR2);
			break;
		}
	}
}
