/*
 *      This program is free software; you can redistribute it and/or modify
 *      it under the terms of the GNU General Public License as published by
 *      the Free Software Foundation; either version 2 of the License, or
 *      (at your option) any later version.
 *      
 *      This program is distributed in the hope that it will be useful,
 *      but WITHOUT ANY WARRANTY; without even the implied warranty of
 *      MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *      GNU General Public License for more details.
 *      
 *      Last Modified : 2 Dec. 2014
 *      Written by Gyeongyong Heo
 *      Contact Info. hgycap@deu.ac.kr
 */
 
int pins[] = {5, 6, 7, 8, 10, 11, 12, 13};	// LED 모듈 연결 핀
String buffer;				// 수신 문자열 저장
// 세 가지 상태 (초기 상태 : 0, 문자열 수신 완료 상태 : 1, 시간 초과 : -1)
int state;	
int TIMEOUT = 20;			// 제한 시간
unsigned long time_start, time_current;

void setup(){
	for(int i = 0; i < 8; i++){		// LED 모듈 연결 핀을 출력으로 설정
		pinMode(pins[i], OUTPUT);
	}

	Serial.begin(9600);
	buffer = "";
	state = 0;

	randomSeed(analogRead(A5));		// 난수 생성기 초기화
}

void loop(){
	int number = random(1, 256);		// [1 255] 범위의 난수 생성
	for(int i = 0; i < 8; i++){		// LED 모듈에 나타내기
		boolean on_off = bitRead(number, i);
		digitalWrite(pins[i], on_off);
	}

	Serial.println();
	Serial.println("Now, start to guess...");

	time_start = millis();			// 시작 시간

	while(true){				// 문자열 입력 대기
		time_current = millis();		// 현재 시간

		if((time_current - time_start) / 1000 > TIMEOUT){	// 시간 초과
			state = -1;
			break;
		}

		while(Serial.available() > 0){		// 수신 버퍼에 문자가 존재하는 경우
			char data = Serial.read();
			if(data == '\n'){			// 문자열 종료 문자인 경우
				state = 1;
				break;
			}
			else{
				buffer += data;
			}
		}

		if(state == 1){			// 문자열 수신이 종료된 경우
			int guess = buffer.toInt();		// 정수로 변환
			state = 0;
			buffer = "";
			Serial.println("You entered " + String(guess));

			if(guess == number){		// 생성된 난수와 입력한 숫자가 일치
				Serial.println("Okay, you are right.");
			}
			else{
				Serial.println("Sorry, do some more math.");
			}

			break;					// 새로운 난수 생성을 위해 종료
		}
	}

	if(state == -1){				// 시간 초과인 경우
		state = 0;
		buffer = "";
		Serial.println("Time out !! Hurry up !!");
	}
}
