/*
 *      This program is free software; you can redistribute it and/or modify
 *      it under the terms of the GNU General Public License as published by
 *      the Free Software Foundation; either version 2 of the License, or
 *      (at your option) any later version.
 *      
 *      This program is distributed in the hope that it will be useful,
 *      but WITHOUT ANY WARRANTY; without even the implied warranty of
 *      MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *      GNU General Public License for more details.
 *      
 *      Last Modified : 2 Dec. 2014
 *      Written by Gyeongyong Heo
 *      Contact Info. hgycap@deu.ac.kr
 */
 
// 0에서 9까지 숫자 표현을 위한
// 세그먼트 a, b, c, d, e, f, g, dp의 패턴
byte patterns[] = {
	0xFC, 0x60, 0xDA, 0xF2, 0x66, 0xB6, 0xBE, 0xE4, 0xFE, 0xE6
};

int pins[] = {5, 6, 7, 8, 10, 11, 12, 13};	// 7세그먼트 모듈 연결 핀
int button_pin = 9;			// 풀다운 버튼 연결
int index;						// 현재 출력 숫자

unsigned long time_previous, time_current;

int INTERVAL = 100;			// 숫자 전환 시간 (ms)

void setup(){
	for(int i = 0; i < 8; i++){	// 7세그먼트 모듈 연결 핀을 출력으로 설정
		pinMode(pins[i], OUTPUT);
	}
	pinMode(button_pin, INPUT);		// 버튼 연결 핀을 입력으로 설정

	index = 0;					// 현재 출력 숫자
	Serial.begin(9600);
	randomSeed(analogRead(A5));		// 난수 생성기 초기화
}

void loop(){
	time_previous = millis();
	int number = random(0, 10);			// [0 9] 난수 생성
	Serial.println();
	Serial.println("Hit " + String(number) + " !!");	// 생성된 난수 표시

	while(true){
		boolean button = digitalRead(button_pin);
		if(button){			// 버튼을 누른 경우 난수와 현재 표시 숫자 비교
			delay(500);			// 디바운스
			break;
		}

		time_current = millis();
		if(time_current - time_previous >= INTERVAL){
			time_previous = time_current;

			index = (index + 1) % 10;

			for(int i = 0; i < 8; i++){
				boolean on_off = bitRead(patterns[index], i);
				digitalWrite(pins[7 - i], on_off);
			}
		}
	}

	Serial.println("You pressed when " + String(index) + "...");
	if(number == index){			// 생성된 난수와 현재 표시 숫자가 일치
		Serial.println("Okay ! Good job !!");
	}
	else{
		Serial.println("Do some more practice !");
	}

	Serial.println("Press button to start again...");
	while(!digitalRead(button_pin));		// 다시 시도하기 위해 버튼 입력 대기
	delay(500);					// 디바운스
}
