/*
 *      This program is free software; you can redistribute it and/or modify
 *      it under the terms of the GNU General Public License as published by
 *      the Free Software Foundation; either version 2 of the License, or
 *      (at your option) any later version.
 *      
 *      This program is distributed in the hope that it will be useful,
 *      but WITHOUT ANY WARRANTY; without even the implied warranty of
 *      MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *      GNU General Public License for more details.
 *      
 *      Last Modified : 2 Dec. 2014
 *      Written by Gyeongyong Heo
 *      Contact Info. hgycap@deu.ac.kr
 */
 
// 0에서 9까지 숫자 표현을 위한
// 세그먼트 a, b, c, d, e, f, g, dp의 패턴
byte patterns[] = {
	0xFC, 0x60, 0xDA, 0xF2, 0x66, 0xB6, 0xBE, 0xE4, 0xFE, 0xE6
};
byte symbols[] = { 0x02, 0x12 };			// 마이너스 및 등호 기호

int digit_select_pin[] = {12, 13, A0, A1};		// 자릿수 선택 핀
// 7세그먼트 모듈 연결 핀 ‘a, b, c, d, e, f, g, dp’ 순서
int segment_pin[] = {2, 3, 5, 6, 7, 8, 10, 11};

int SEGMENT_DELAY = 5;			// 숫자 표시 사이의 시간 간격
String answer = "";				// 수신된 정답 문자열
boolean process = false;

void setup(){
	for(int i = 0; i < 4; i++){		// 자릿수 선택 핀을 출력으로 설정
		pinMode(digit_select_pin[i], OUTPUT);
	}
	for(int i = 0; i < 8; i++){		// 세그먼트 제어 핀을 출력으로 설정
		pinMode(segment_pin[i], OUTPUT);
	}
	randomSeed(analogRead(A5));		// 난수 생성 초기화
	Serial.begin(9600);
}

// 해당 자리에 숫자 하나를 표시하는 함수
void show_digit(int pos, int number){	// (위치, 출력할 숫자)
	for(int i = 0; i < 4; i++){
		if(i + 1 == pos)			// 해당 자릿수의 선택 핀만 LOW로 설정
			digitalWrite(digit_select_pin[i], LOW);
		else							// 나머지 자리는 HIGH로 설정
			digitalWrite(digit_select_pin[i], HIGH);
	}
  
	for(int i = 0; i < 8; i++){
		boolean on_off = bitRead(patterns[number], 7 - i);
		digitalWrite(segment_pin[i], on_off);
	}
}

// 해당 자리에 기호를 표시하는 함수
void show_symbol(int pos, byte data){
	for(int i = 0; i < 4; i++){
		if(i + 1 == pos)			// 해당 자릿수의 선택 핀만 LOW로 설정
			digitalWrite(digit_select_pin[i], LOW);
		else							// 나머지 자리는 HIGH로 설정
			digitalWrite(digit_select_pin[i], HIGH);
	}
  
	for(int i = 0; i < 8; i++){
		boolean on_off = bitRead(data, 7 - i);
		digitalWrite(segment_pin[i], on_off);
	}
}

// ‘A-B=’ 형식으로 문제를 4자리 7세그먼트 표시장치에 표시
void show_equation(int A, int B){
	show_digit(1, A);
	delay(SEGMENT_DELAY);
	show_symbol(2, symbols[0]);
	delay(SEGMENT_DELAY);
	show_digit(3, B);
	delay(SEGMENT_DELAY);
	show_symbol(4, symbols[1]);
	delay(SEGMENT_DELAY);
}

void loop(){
	int A = random(0, 10);		// 난수 생성
	int B = random(0, 10);

	Serial.println(String("What's the answer of ") + A + "-" + B);

	while(!process){
		show_equation(A, B);

		if(Serial.available()){		// 시리얼 모니터를 통해 입력된 정답 문자열 조합
			char received = Serial.read();
			if(received == '\n') process = true;
			else answer = answer + received;
		}
		if(process){			// 문자열 끝인 ‘\n’ 감지
			Serial.println(String("  You typed ") + answer);
			int no = answer.toInt();	// 문자열을 숫자로 변환
			answer = "";

			if(no == A - B) Serial.println("  Correct !!");
			else Serial.println("  Not Correct...");
		}
	}

	process = false;
}
