/*
 *      This program is free software; you can redistribute it and/or modify
 *      it under the terms of the GNU General Public License as published by
 *      the Free Software Foundation; either version 2 of the License, or
 *      (at your option) any later version.
 *      
 *      This program is distributed in the hope that it will be useful,
 *      but WITHOUT ANY WARRANTY; without even the implied warranty of
 *      MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *      GNU General Public License for more details.
 *      
 *      Last Modified : 2 Dec. 2014
 *      Written by Gyeongyong Heo
 *      Contact Info. hgycap@deu.ac.kr
 */
 
#include "Arduino.h"
#include "DMUStyleMotor.h"

_DMUStyleMotor DMUStyleMotor;			// 전역 객체

_DMUStyleMotor::_DMUStyleMotor()
{
	PWM1 = 9;
	Enable1 = 10;
	DIR1 = 11;

	PWM2 = 6;
	Enable2 = 7;
	DIR2 = 8;
	
	Init();				// 핀 모드 설정
}

void _DMUStyleMotor::SetPins(int dir1, int enable1, int pwm1, 
			int dir2, int enable2, int pwm2)
{	
	PWM1 = pwm1;
	Enable1 = enable1;
	DIR1 = dir1;

	PWM2 = pwm2;
	Enable2 = enable2;
	DIR2 = dir2;
	
	Init();
}

void _DMUStyleMotor::Init()
{
	pinMode(PWM1, OUTPUT);
	pinMode(Enable1, OUTPUT);
	pinMode(DIR1, OUTPUT);

	pinMode(PWM2, OUTPUT);
	pinMode(Enable2, OUTPUT);
	pinMode(DIR2, OUTPUT);

	digitalWrite(Enable1, HIGH);		// 비활성화 상태
	digitalWrite(Enable2, HIGH);
}

// 모터를 지정한 방향과 속도로 회전시킨다.
// motor : 모터 선택 (1 또는 2)
// dir : 방향 (1 또는 2)
// speed : 속도 (0~255)
void _DMUStyleMotor::Rotate(int motor, int dir, int speed)
{
	switch(motor){
	case MOTOR1:
		if(dir == DIRECTION1) digitalWrite(DIR1, HIGH);
		else digitalWrite(DIR1, LOW);
		analogWrite(PWM1, speed);
		break;
	case MOTOR2:
		if(dir == DIRECTION1) digitalWrite(DIR2, HIGH);
		else digitalWrite(DIR2, LOW);
		analogWrite(PWM2, speed);
		break;
	}
}

// 모터 회전을 정지시킨다.
void _DMUStyleMotor::Stop(int motor)
{
	switch(motor){
	case MOTOR1:
		analogWrite(PWM1, 0);
		break;
	case MOTOR2:
		analogWrite(PWM2, 0);
		break;
	}
}

// 모터를 활성화 상태로 설정한다.
void _DMUStyleMotor::Enable(int motor)
{
	switch(motor){
	case MOTOR1:
		digitalWrite(Enable1, LOW);
		break;
	case MOTOR2:
		digitalWrite(Enable2, LOW);
		break;
	}
}

// 모터를 비활성화 상태로 설정한다.
void _DMUStyleMotor::Disable(int motor)
{
	switch(motor){
	case MOTOR1:
		digitalWrite(Enable1, HIGH);
		break;
	case MOTOR2:
		digitalWrite(Enable2, HIGH);
		break;
	}	
}